@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: e1f4ef62622ef222ff6df750254ece3184fd53ef $ */
+/* $Id: 771e31632526e20243748d73c150d8977fff1781 $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -321,7 +321,7 @@ const zend_function_entry posix_functions[] = {
 static PHP_MINFO_FUNCTION(posix)
 {
 	php_info_print_table_start();
-	php_info_print_table_row(2, "Revision", "$Id: e1f4ef62622ef222ff6df750254ece3184fd53ef $");
+	php_info_print_table_row(2, "Revision", "$Id: 771e31632526e20243748d73c150d8977fff1781 $");
 	php_info_print_table_end();
 }
 /* }}} */
@@ -987,8 +987,12 @@ int php_posix_group_to_array(struct group *g, zval *array_group) /* {{{ */
 	array_init(&array_members);
 
 	add_assoc_string(array_group, "name", g->gr_name);
-	add_assoc_string(array_group, "passwd", g->gr_passwd);
-	for (count=0; g->gr_mem[count] != NULL; count++) {
+	if (g->gr_passwd) {
+		add_assoc_string(array_group, "passwd", g->gr_passwd);
+	} else {
+		add_assoc_null(array_group, "passwd");
+	}
+	for (count = 0; g->gr_mem[count] != NULL; count++) {
 		add_next_index_string(&array_members, g->gr_mem[count]);
 	}
 	zend_hash_str_update(Z_ARRVAL_P(array_group), "members", sizeof("members")-1, &array_members);
