@@ -26,9 +26,7 @@
 #include "zend_vm.h"
 #include "zend_generators.h"
 #include "zend_interfaces.h"
-#include "zend_smart_str.h"
 #include "phpdbg.h"
-#include "phpdbg_io.h"
 
 #include "phpdbg_help.h"
 #include "phpdbg_print.h"
@@ -70,7 +68,6 @@ extern int phpdbg_startup_run;
 /* {{{ command declarations */
 const phpdbg_command_t phpdbg_prompt_commands[] = {
 	PHPDBG_COMMAND_D(exec,    "set execution context",                    'e', NULL, "s", 0),
-	PHPDBG_COMMAND_D(stdin,   "read script from stdin",                    0 , NULL, "s", 0),
 	PHPDBG_COMMAND_D(step,    "step through execution",                   's', NULL, 0, PHPDBG_ASYNC_SAFE),
 	PHPDBG_COMMAND_D(continue,"continue execution",                       'c', NULL, 0, PHPDBG_ASYNC_SAFE),
 	PHPDBG_COMMAND_D(run,     "attempt execution",                        'r', NULL, "|s", 0),
@@ -388,7 +385,7 @@ void phpdbg_init(char *init_file, size_t init_file_len, zend_bool use_default) /
 }
 /* }}} */
 
-void phpdbg_clean(zend_bool full, zend_bool resubmit) /* {{{ */
+void phpdbg_clean(zend_bool full) /* {{{ */
 {
 	/* this is implicitly required */
 	if (PHPDBG_G(ops)) {
@@ -397,11 +394,6 @@ void phpdbg_clean(zend_bool full, zend_bool resubmit) /* {{{ */
 		PHPDBG_G(ops) = NULL;
 	}
 
-	if (!resubmit && PHPDBG_G(cur_command)) {
-		free(PHPDBG_G(cur_command));
-		PHPDBG_G(cur_command) = NULL;
-	}
-
 	if (full) {
 		PHPDBG_G(flags) |= PHPDBG_IS_CLEANING;
 	}
@@ -432,7 +424,7 @@ PHPDBG_COMMAND(exec) /* {{{ */
 
 				if (PHPDBG_G(ops)) {
 					phpdbg_notice("exec", "type=\"unsetops\"", "Destroying compiled opcodes");
-					phpdbg_clean(0, 0);
+					phpdbg_clean(0);
 				}
 
 				PHPDBG_G(exec) = res;
@@ -446,7 +438,7 @@ PHPDBG_COMMAND(exec) /* {{{ */
 				phpdbg_notice("exec", "type=\"set\" context=\"%s\"", "Set execution context: %s", PHPDBG_G(exec));
 
 				if (PHPDBG_G(in_execution)) {
-					phpdbg_clean(1, 0);
+					phpdbg_clean(1);
 					return SUCCESS;
 				}
 
@@ -463,111 +455,6 @@ PHPDBG_COMMAND(exec) /* {{{ */
 	return SUCCESS;
 } /* }}} */
 
-PHPDBG_COMMAND(stdin)
-{
-	smart_str code = {0};
-	char *buf;
-	char *sep = param->str;
-	int seplen = param->len;
-	int bytes = 0;
-
-	smart_str_appends(&code, "?>");
-
-	do {
-		PHPDBG_G(input_buflen) += bytes;
-		if (PHPDBG_G(input_buflen) <= 0) {
-			continue;
-		}
-
-		if (sep && seplen) {
-			char *nl = buf = PHPDBG_G(input_buffer);
-			do {
-				if (buf == nl + seplen) {
-					if (!memcmp(sep, nl, seplen) && (*buf == '\n' || (*buf == '\r' && buf[1] == '\n'))) {
-						smart_str_appendl(&code, PHPDBG_G(input_buffer), nl - PHPDBG_G(input_buffer));
-						memmove(PHPDBG_G(input_buffer), ++buf, --PHPDBG_G(input_buflen));
-						goto exec_code;
-					}
-				}
-				if (*buf == '\n') {
-					nl = buf + 1;
-				}
-				buf++;
-			} while (--PHPDBG_G(input_buflen));
-			if (buf != nl && buf <= nl + seplen) {
-				smart_str_appendl(&code, PHPDBG_G(input_buffer), nl - PHPDBG_G(input_buffer));
-				PHPDBG_G(input_buflen) = buf - nl;
-				memmove(PHPDBG_G(input_buffer), nl, PHPDBG_G(input_buflen));
-			} else {
-				PHPDBG_G(input_buflen) = 0;
-				smart_str_appendl(&code, PHPDBG_G(input_buffer), buf - PHPDBG_G(input_buffer));
-			}
-		} else {
-			smart_str_appendl(&code, PHPDBG_G(input_buffer), PHPDBG_G(input_buflen));
-			PHPDBG_G(input_buflen) = 0;
-		}
-	} while ((bytes = phpdbg_mixed_read(PHPDBG_G(io)[PHPDBG_STDIN].fd, PHPDBG_G(input_buffer) + PHPDBG_G(input_buflen), PHPDBG_MAX_CMD - PHPDBG_G(input_buflen), -1)) > 0);
-
-	if (bytes < 0) {
-		PHPDBG_G(flags) |= PHPDBG_IS_QUITTING | PHPDBG_IS_DISCONNECTED;
-		zend_bailout();
-	}
-
-exec_code:
-	smart_str_0(&code);
-
-	if (phpdbg_compile_stdin(code.s) == FAILURE) {
-		zend_exception_error(EG(exception), E_ERROR);
-		zend_bailout();
-	}
-
-	return SUCCESS;
-} /* }}} */
-
-int phpdbg_compile_stdin(zend_string *code) {
-	zval zv;
-
-	ZVAL_STR(&zv, code);
-
-	PHPDBG_G(ops) = zend_compile_string(&zv, "-");
-
-	zend_string_release(code);
-
-	if (EG(exception)) {
-		return FAILURE;
-	}
-
-	if (PHPDBG_G(exec)) {
-		efree(PHPDBG_G(exec));
-	}
-	PHPDBG_G(exec) = estrdup("-");
-	PHPDBG_G(exec_len) = 1;
-	{ /* remove leading ?> from source */
-		int i;
-		zend_string *source_path = strpprintf(0, "-%c%p", 0, PHPDBG_G(ops)->opcodes);
-		phpdbg_file_source *data = zend_hash_find_ptr(&PHPDBG_G(file_sources), source_path);
-		dtor_func_t dtor = PHPDBG_G(file_sources).pDestructor;
-		PHPDBG_G(file_sources).pDestructor = NULL;
-		zend_hash_del(&PHPDBG_G(file_sources), source_path);
-		PHPDBG_G(file_sources).pDestructor = dtor;
-		zend_hash_str_update_ptr(&PHPDBG_G(file_sources), "-", 1, data);
-		zend_string_release(source_path);
-
-		efree(data->filename);
-		data->filename = estrdup("-");
-
-		for (i = 1; i <= data->lines; i++) {
-			data->line[i] -= 2;
-		}
-		data->len -= 2;
-		memmove(data->buf, data->buf + 2, data->len);
-	}
-
-	phpdbg_notice("compile", "context=\"-\"", "Successful compilation of stdin input");
-
-	return SUCCESS;
-}
-
 int phpdbg_compile(void) /* {{{ */
 {
 	zend_file_handle fh;
@@ -789,7 +676,7 @@ PHPDBG_COMMAND(run) /* {{{ */
 		if (PHPDBG_G(in_execution)) {
 			if (phpdbg_ask_user_permission("Do you really want to restart execution?") == SUCCESS) {
 				phpdbg_startup_run++;
-				phpdbg_clean(1, 1);
+				phpdbg_clean(1);
 			}
 			return SUCCESS;
 		}
@@ -801,97 +688,6 @@ PHPDBG_COMMAND(run) /* {{{ */
 			}
 		}
 
-		if (param && param->type != EMPTY_PARAM && param->len != 0) {
-			char **argv = emalloc(5 * sizeof(char *));
-			char *end = param->str + param->len, *p = param->str;
-			int argc = 0;
-			int i;
-
-			while (*end == '\r' || *end == '\n') *(end--) = 0;
-
-			while (*p == ' ') p++;
-			while (*p) {
-				char sep = ' ';
-				char *buf = emalloc(end - p + 1), *q = buf;
-
-				if (*p == '<') {
-					/* use as STDIN */
-					do p++; while (*p == ' ');
-
-					if (*p == '\'' || *p == '"') {
-						sep = *(p++);
-					}
-					while (*p && *p != sep) {
-						if (*p == '\\' && (p[1] == sep || p[1] == '\\')) {
-							p++;
-						}
-						*(q++) = *(p++);
-					}
-					*(q++) = 0;
-					if (*p) {
-						do p++; while (*p == ' ');
-					}
-
-					if (*p) {
-						phpdbg_error("cmd", "", "Invalid run command, cannot put further arguments after stdin");
-						goto free_cmd;
-					}
-
-					PHPDBG_G(stdin_file) = fopen(buf, "r");
-					if (PHPDBG_G(stdin_file) == NULL) {
-						phpdbg_error("stdin", "path=\"%s\"", "Could not open '%s' for reading from stdin", buf);
-						goto free_cmd;
-					}
-					efree(buf);
-					phpdbg_register_file_handles();
-					break;
-				}
-
-				if (argc >= 4 && argc == (argc & -argc)) {
-					argv = erealloc(argv, (argc * 2 + 1) * sizeof(char *));
-				}
-
-				if (*p == '\'' || *p == '"') {
-					sep = *(p++);
-				}
-				if (*p == '\\' && (p[1] == '<' || p[1] == '\'' || p[1] == '"')) {
-					p++;
-				}
-				while (*p && *p != sep) {
-					if (*p == '\\' && (p[1] == sep || p[1] == '\\' || (p[1] == '#' && sep == ' '))) {
-						p++;
-					}
-					*(q++) = *(p++);
-				}
-				if (!*p && sep != ' ') {
-					phpdbg_error("cmd", "", "Invalid run command, unterminated escape sequence");
-free_cmd:
-					efree(buf);
-					for (i = 0; i < argc; i++) {
-						efree(argv[i]);
-					}
-					efree(argv);
-					return SUCCESS;
-				}
-
-				*(q++) = 0;
-				argv[++argc] = erealloc(buf, q - buf);
-
-				if (*p) {
-					do p++; while (*p == ' ');
-				}
-			}
-			argv[0] = SG(request_info).argv[0];
-			for (i = SG(request_info).argc; --i;) {
-				efree(SG(request_info).argv[i]);
-			}
-			efree(SG(request_info).argv);
-			SG(request_info).argv = erealloc(argv, ++argc * sizeof(char *));
-			SG(request_info).argc = argc;
-
-			php_build_argv(NULL, &PG(http_globals)[TRACK_VARS_SERVER]);
-		}
-
 		/* clean up from last execution */
 		if (ex && ex->symbol_table) {
 			zend_hash_clean(ex->symbol_table);
@@ -907,6 +703,32 @@ free_cmd:
 		/* reset hit counters */
 		phpdbg_reset_breakpoints();
 
+		if (param && param->type != EMPTY_PARAM && param->len != 0) {
+			char **argv = emalloc(5 * sizeof(char *));
+			int argc = 0;
+			int i;
+			/* TODO allow proper escaping with \,  "" and '' here */
+			char *argv_str = strtok(param->str, " ");
+
+			while (argv_str) {
+				if (argc >= 4 && argc == (argc & -argc)) {
+					argv = erealloc(argv, (argc * 2 + 1) * sizeof(char *));
+				}
+				argv[++argc] = argv_str;
+				argv_str = strtok(0, " ");
+				argv[argc] = estrdup(argv[argc]);
+			}
+			argv[0] = SG(request_info).argv[0];
+			for (i = SG(request_info).argc; --i;) {
+				efree(SG(request_info).argv[i]);
+			}
+			efree(SG(request_info).argv);
+			SG(request_info).argv = erealloc(argv, ++argc * sizeof(char *));
+			SG(request_info).argc = argc;
+
+			php_build_argv(NULL, &PG(http_globals)[TRACK_VARS_SERVER]);
+		}
+
 		zend_try {
 			PHPDBG_G(flags) ^= PHPDBG_IS_INTERACTIVE;
 			PHPDBG_G(flags) |= PHPDBG_IS_RUNNING;
@@ -947,7 +769,7 @@ free_cmd:
 
 		PHPDBG_G(flags) &= ~PHPDBG_IS_RUNNING;
 
-		phpdbg_clean(1, 0);
+		phpdbg_clean(1);
 	} else {
 		phpdbg_error("inactive", "type=\"nocontext\"", "Nothing to execute!");
 	}
@@ -1127,21 +949,16 @@ PHPDBG_COMMAND(set) /* {{{ */
 PHPDBG_COMMAND(break) /* {{{ */
 {
 	if (!param) {
-		if (PHPDBG_G(exec)) {
-			phpdbg_set_breakpoint_file_ex(
-				zend_get_executed_filename(),
-				strlen(zend_get_executed_filename()),
-				zend_get_executed_lineno());
-		} else {
-			phpdbg_error("inactive", "type=\"noexec\"", "Execution context not set!");
-		}
+		phpdbg_set_breakpoint_file(
+			zend_get_executed_filename(),
+			zend_get_executed_lineno());
 	} else switch (param->type) {
 		case ADDR_PARAM:
 			phpdbg_set_breakpoint_opline(param->addr);
 			break;
 		case NUMERIC_PARAM:
 			if (PHPDBG_G(exec)) {
-				phpdbg_set_breakpoint_file_ex(phpdbg_current_file(), strlen(phpdbg_current_file()), param->num);
+				phpdbg_set_breakpoint_file(phpdbg_current_file(), param->num);
 			} else {
 				phpdbg_error("inactive", "type=\"noexec\"", "Execution context not set!");
 			}
@@ -1456,7 +1273,7 @@ PHPDBG_COMMAND(clean) /* {{{ */
 	phpdbg_writeln("clean", "constants=\"%d\"", "Constants  %d", zend_hash_num_elements(EG(zend_constants)));
 	phpdbg_writeln("clean", "includes=\"%d\"", "Includes   %d", zend_hash_num_elements(&EG(included_files)));
 
-	phpdbg_clean(1, 0);
+	phpdbg_clean(1);
 
 	phpdbg_xml("</cleaninfo>");
 
@@ -1525,9 +1342,10 @@ PHPDBG_COMMAND(watch) /* {{{ */
 	return SUCCESS;
 } /* }}} */
 
-int phpdbg_interactive(zend_bool allow_async_unsafe, char *input) /* {{{ */
+int phpdbg_interactive(zend_bool allow_async_unsafe) /* {{{ */
 {
 	int ret = SUCCESS;
+	char *input = NULL;
 	phpdbg_param_t stack;
 
 	PHPDBG_G(flags) |= PHPDBG_IS_INTERACTIVE;
@@ -1537,7 +1355,7 @@ int phpdbg_interactive(zend_bool allow_async_unsafe, char *input) /* {{{ */
 			zend_bailout();
 		}
 
-		if (!input && !(input = phpdbg_read_input(NULL))) {
+		if (!(input = phpdbg_read_input(NULL))) {
 			break;
 		}
 
@@ -1627,7 +1445,7 @@ int phpdbg_interactive(zend_bool allow_async_unsafe, char *input) /* {{{ */
 		efree(file); \
 	} \
 	\
-	switch (phpdbg_interactive(allow_async_unsafe, NULL)) { \
+	switch (phpdbg_interactive(allow_async_unsafe)) { \
 		zval zv; \
 		case PHPDBG_LEAVE: \
 		case PHPDBG_FINISH: \
